print("import: 'OpenSSL'")
import OpenSSL

print("import: 'OpenSSL.crypto'")
import OpenSSL.crypto

print("import: 'OpenSSL.rand'")
import OpenSSL.rand

print("import: 'OpenSSL.SSL'")
import OpenSSL.SSL

